==> rtkore_1.1.0.tar.gz: rtkore/inst/NEWS.Rd <==
\name{NEWS}
\title{News for Package 'rtkore}

\section{Changes in rtkore version 1.1.0 (2016-0530)}{
  \itemize{
    \item Adding svd decomposition using lapack in Algebra project
    \item Adding online mean ancd variance computation in STatistiK project
    \item Adding kernels classes in STatistiK project
    \item Adding class Factor allowing to use factor rather than original
    nominal data encoding in STatistiK project
    \item Corecting many small bugs
  }
}
\section{Changes in rtkore version 1.0.1 (2015-1124)}{
  \itemize{
    \item First release of the rtkore package, successor of the rtkpp package.
  }
}
\section{Changes in rtkpp version 0.9.2 (2015-07-30)}{
  \itemize{
    \item Creating fixed size allocators and Array1D
    \item Adding support for the kernel mixture models
    \item Adding miscellaneous kernels in STatistiK project
  }
}
\section{Changes in rtkpp version 0.9.0 (2014-12-01)}{
  \itemize{
    \item Provide more templated classes reducing the size of the library
    \item Adding GaussianKernel mixture models
  }
}
\section{Changes in rtkpp version 0.8.5 (2014-12-01)}{
  \itemize{
    \item Using openmp support
    \item using accelerated new version of the stk++ library
    \item adding factors to the categorical mixtures
    \item many bug corrections
  }
}
\section{Changes in rtkpp version 0.8.4 (2014-11-06)}{
  \itemize{
    \item Adding clusterHeterogeneous method for clustering heterogeneous data
  }
}
\section{Changes in rtkpp version 0.8.3 (2014-10-23)}{
  \itemize{
    \item The source package can be build using parallel make
    \item Documentation has been slightly enhanced
    \item cluster methods allow the 1 classe case
  }
}
\section{Changes in rtkpp version 0.8.2 (2014-10-20)}{
  \itemize{
    \item Upgraded to stkpp 0.8.2
  }
}

==> rtkore_1.2.0.tar.gz: rtkore/inst/NEWS.Rd <==
\name{NEWS}
\title{News for Package 'rtkore}

\section{Changes in rtkore version 1.2.0 (2016-11-20)}{
  \itemize{
    \item Adding more vignettes about STK++ arrays
    \item Creating Factor class for vectors and MultiFactor class for arrays in STatistiK project
    \item Adding CvHandler class in DManager project for cross validation
  }
}
\section{Changes in rtkore version 1.1.1 (2016-08-04)}{
  \itemize{
    \item Creating and Implementing InvertMatrix and InvertSymMatrix classes
    for fixed size matrices (up to 4x4)
    \item Adding computation of levels and frequence to the Factor class
  }
}
\section{Changes in rtkore version 1.1.0 (2016-05-30)}{
  \itemize{
    \item Adding svd decomposition using lapack in Algebra project
    \item Adding online mean ancd variance computation in STatistiK project
    \item Adding kernels classes in STatistiK project
    \item Adding class Factor allowing to use factor rather than original
    nominal data encoding in STatistiK project
    \item Correcting many small bugs
  }
}
\section{Changes in rtkore version 1.0.1 (2015-11-24)}{
  \itemize{
    \item First release of the rtkore package, successor of the rtkpp package.
  }
}
\section{Changes in rtkpp version 0.9.2 (2015-07-30)}{
  \itemize{
    \item Creating fixed size allocators and Array1D
    \item Adding support for the kernel mixture models
    \item Adding miscellaneous kernels in STatistiK project
  }
}
\section{Changes in rtkpp version 0.9.0 (2014-12-01)}{
  \itemize{
    \item Provide more templated classes reducing the size of the library
    \item Adding GaussianKernel mixture models
  }
}
\section{Changes in rtkpp version 0.8.5 (2014-12-01)}{
  \itemize{
    \item Using openmp support
    \item using accelerated new version of the stk++ library
    \item adding factors to the categorical mixtures
    \item many bug corrections
  }
}
\section{Changes in rtkpp version 0.8.4 (2014-11-06)}{
  \itemize{
    \item Adding clusterHeterogeneous method for clustering heterogeneous data
  }
}
\section{Changes in rtkpp version 0.8.3 (2014-10-23)}{
  \itemize{
    \item The source package can be build using parallel make
    \item Documentation has been slightly enhanced
    \item cluster methods allow the 1 classe case
  }
}
\section{Changes in rtkpp version 0.8.2 (2014-10-20)}{
  \itemize{
    \item Upgraded to stkpp 0.8.2
  }
}
